@@ -11,7 +11,12 @@ use super::{
     extract_partials_return_type, parse_vector_trailing_till_double_comma, Attributes,
     ExtendWithFunctionAttrs, Fixture,
 };
-use crate::{error::ErrorsVec, refident::RefIdent, utils::attr_is};
+use crate::{
+    error::ErrorsVec,
+    parse::extract_once,
+    refident::{MaybeIdent, RefIdent},
+    utils::attr_is,
+};
 use crate::{parse::Attribute, utils::attr_in};
 use proc_macro2::TokenStream;
 use quote::{format_ident, ToTokens};
@@ -53,12 +58,14 @@ impl ExtendWithFunctionAttrs for FixtureInfo {
             fixtures,
             defaults,
             default_return_type,
-            partials_return_type
+            partials_return_type,
+            once
         ) = merge_errors!(
             extract_fixtures(item_fn),
             extract_defaults(item_fn),
             extract_default_return_type(item_fn),
-            extract_partials_return_type(item_fn)
+            extract_partials_return_type(item_fn),
+            extract_once(item_fn)
         )?;
         self.data.items.extend(
             fixtures
@@ -72,6 +79,9 @@ impl ExtendWithFunctionAttrs for FixtureInfo {
         for (id, return_type) in partials_return_type {
             self.attributes.set_partial_return_type(id, return_type);
         }
+        if let Some(ident) = once {
+            self.attributes.set_once(ident)
+        };
         Ok(())
     }
 }
@@ -174,7 +184,7 @@ impl FixtureData {
 
     pub(crate) fn values(&self) -> impl Iterator<Item = &ArgumentValue> {
         self.items.iter().filter_map(|f| match f {
-            FixtureItem::ArgumentValue(ref value) => Some(value),
+            FixtureItem::ArgumentValue(ref value) => Some(value.as_ref()),
             _ => None,
         })
     }
@@ -207,7 +217,7 @@ impl ArgumentValue {
 #[derive(PartialEq, Debug)]
 pub(crate) enum FixtureItem {
     Fixture(Fixture),
-    ArgumentValue(ArgumentValue),
+    ArgumentValue(Box<ArgumentValue>),
 }
 
 impl From<Fixture> for FixtureItem {
@@ -230,7 +240,7 @@ impl RefIdent for FixtureItem {
     fn ident(&self) -> &Ident {
         match self {
             FixtureItem::Fixture(Fixture { ref name, .. }) => name,
-            FixtureItem::ArgumentValue(ArgumentValue { ref name, .. }) => name,
+            FixtureItem::ArgumentValue(ref av) => &av.name,
         }
     }
 }
@@ -243,7 +253,7 @@ impl ToTokens for FixtureItem {
 
 impl From<ArgumentValue> for FixtureItem {
     fn from(av: ArgumentValue) -> Self {
-        FixtureItem::ArgumentValue(av)
+        FixtureItem::ArgumentValue(Box::new(av))
     }
 }
 
@@ -273,17 +283,31 @@ impl FixtureModifiers {
     pub(crate) fn set_default_return_type(&mut self, return_type: syn::Type) {
         self.inner.attributes.push(Attribute::Type(
             format_ident!("{}", Self::DEFAULT_RET_ATTR),
-            return_type,
+            Box::new(return_type),
         ))
     }
 
     pub(crate) fn set_partial_return_type(&mut self, id: usize, return_type: syn::Type) {
         self.inner.attributes.push(Attribute::Type(
             format_ident!("{}{}", Self::PARTIAL_RET_ATTR, id),
-            return_type,
+            Box::new(return_type),
         ))
     }
 
+    pub(crate) fn set_once(&mut self, once: syn::Ident) {
+        self.inner.attributes.push(Attribute::Attr(once))
+    }
+
+    pub(crate) fn get_once(&self) -> Option<&Ident> {
+        self.iter()
+            .find(|&a| a == &Attribute::Attr(format_ident!("once")))
+            .and_then(|a| a.maybe_ident())
+    }
+
+    pub(crate) fn is_once(&self) -> bool {
+        self.get_once().is_some()
+    }
+
     fn extract_type(&self, attr_name: &str) -> Option<syn::ReturnType> {
         self.iter()
             .filter_map(|m| match m {
@@ -533,6 +557,39 @@ mod extend {
             );
         }
 
+        #[test]
+        fn find_once_attribute() {
+            let mut item_fn: ItemFn = r#"
+                #[simple]
+                #[first(comp)]
+                #[second::default]
+                #[once]
+                #[last::more]
+                fn my_fix<I, J, K>(f1: I, f2: J, f3: K) -> impl Iterator<Item=(I, J, K)> {}
+            "#
+            .ast();
+
+            let mut info = FixtureInfo::default();
+
+            info.extend_with_function_attrs(&mut item_fn).unwrap();
+
+            assert!(info.attributes.is_once());
+        }
+
+        #[test]
+        fn no_once_attribute() {
+            let mut item_fn: ItemFn = r#"
+                fn my_fix<I, J, K>(f1: I, f2: J, f3: K) -> impl Iterator<Item=(I, J, K)> {}
+            "#
+            .ast();
+
+            let mut info = FixtureInfo::default();
+
+            info.extend_with_function_attrs(&mut item_fn).unwrap();
+
+            assert!(!info.attributes.is_once());
+        }
+
         mod raise_error {
             use super::{assert_eq, *};
             use rstest_test::assert_in;
@@ -596,6 +653,25 @@ mod extend {
                 assert_eq!(3, errors.len());
             }
 
+            #[test]
+            fn if_once_is_defined_more_than_once() {
+                let mut item_fn: ItemFn = r#"
+                    #[once]
+                    #[once]
+                    fn my_fix<I>() -> I {}
+                    "#
+                .ast();
+
+                let mut info = FixtureInfo::default();
+
+                let error = info.extend_with_function_attrs(&mut item_fn).unwrap_err();
+
+                assert_in!(
+                    format!("{:?}", error).to_lowercase(),
+                    "cannot use #[once] more than once"
+                );
+            }
+
             #[test]
             fn if_default_is_defined_more_than_once() {
                 let mut item_fn: ItemFn = r#"
