@@ -7,7 +7,7 @@ use syn::{parse_quote, Expr, FnArg, Ident, Stmt, Type};
 use crate::{
     refident::{MaybeIdent, MaybeType},
     resolver::Resolver,
-    utils::IsLiteralExpression,
+    utils::{fn_arg_mutability, IsLiteralExpression},
 };
 
 pub(crate) fn resolve_aruments<'a>(
@@ -44,26 +44,31 @@ where
 
     fn resolve(&self, arg: &FnArg) -> Option<Stmt> {
         let ident = arg.maybe_ident()?;
+        let mutability = fn_arg_mutability(arg);
+        let unused_mut: Option<syn::Attribute> = mutability
+            .as_ref()
+            .map(|_| parse_quote! {#[allow(unused_mut)]});
         let arg_type = arg.maybe_type()?;
         let fixture_name = self.fixture_name(ident);
 
         let mut fixture = self
             .resolver
-            .resolve(&fixture_name)
-            .map(|e| e.clone())
+            .resolve(ident)
+            .or_else(|| self.resolver.resolve(&fixture_name))
             .unwrap_or_else(|| default_fixture_resolve(&fixture_name));
 
         if fixture.is_literal() && self.type_can_be_get_from_literal_str(arg_type) {
             fixture = Cow::Owned((self.magic_conversion)(fixture, arg_type));
         }
         Some(parse_quote! {
-            let #ident = #fixture;
+            #unused_mut
+            let #mutability #ident = #fixture;
         })
     }
 
     fn fixture_name<'a>(&self, ident: &'a Ident) -> Cow<'a, Ident> {
         let id_str = ident.to_string();
-        if id_str.starts_with("_") && !id_str.starts_with("__") {
+        if id_str.starts_with('_') && !id_str.starts_with("__") {
             Cow::Owned(Ident::new(&id_str[1..], ident.span()))
         } else {
             Cow::Borrowed(ident)
@@ -153,13 +158,16 @@ mod should {
         test::{assert_eq, *},
         utils::fn_args,
     };
-    
+
     #[rstest]
     #[case::as_is("fix: String", "let fix = fix::default();")]
     #[case::without_underscore("_fix: String", "let _fix = fix::default();")]
     #[case::do_not_remove_inner_underscores("f_i_x: String", "let f_i_x = f_i_x::default();")]
     #[case::do_not_remove_double_underscore("__fix: String", "let __fix = __fix::default();")]
-    #[case::without_mut("mut fix: String", "let fix = fix::default();")]
+    #[case::preserve_mut_but_annotate_as_allow_unused_mut(
+        "mut fix: String",
+        "#[allow(unused_mut)] let mut fix = fix::default();"
+    )]
     fn call_fixture(#[case] arg_str: &str, #[case] expected: &str) {
         let arg = arg_str.ast();
 
@@ -171,8 +179,10 @@ mod should {
     }
 
     #[rstest]
-    #[case::as_is("mut fix: String", ("fix", expr("bar()")), "let fix = bar();")]
+    #[case::as_is("fix: String", ("fix", expr("bar()")), "let fix = bar();")]
+    #[case::with_allow_unused_mut("mut fix: String", ("fix", expr("bar()")), "#[allow(unused_mut)] let mut fix = bar();")]
     #[case::without_undescore("_fix: String", ("fix", expr("bar()")), "let _fix = bar();")]
+    #[case::without_remove_underscore_if_value("_orig: S", ("_orig", expr("S{}")), r#"let _orig = S{};"#)]
     fn call_given_fixture(
         #[case] arg_str: &str,
         #[case] rule: (&str, Expr),
