@@ -17,7 +17,7 @@ pub(crate) mod fixtures {
 
     pub(crate) fn get<'a>(fixtures: impl Iterator<Item = &'a Fixture>) -> impl Resolver + 'a {
         fixtures
-            .map(|f| (f.name.to_string(), extract_resolve_expression(f).into()))
+            .map(|f| (f.name.to_string(), extract_resolve_expression(f)))
             .collect::<HashMap<_, Expr>>()
     }
 
@@ -114,7 +114,7 @@ impl<'a> Resolver for HashMap<String, &'a Expr> {
 impl<'a> Resolver for HashMap<String, Expr> {
     fn resolve(&self, ident: &Ident) -> Option<Cow<Expr>> {
         let ident = ident.to_string();
-        self.get(&ident).map(|c| Cow::Borrowed(c))
+        self.get(&ident).map(Cow::Borrowed)
     }
 }
 
@@ -138,7 +138,7 @@ impl<R: Resolver + ?Sized> Resolver for Box<R> {
 
 impl Resolver for (String, Expr) {
     fn resolve(&self, ident: &Ident) -> Option<Cow<Expr>> {
-        if self.0 == ident.to_string() {
+        if *ident == self.0 {
             Some(Cow::Borrowed(&self.1))
         } else {
             None
