@@ -19,6 +19,8 @@ fn run_test(res: &str) -> (std::process::Output, String) {
 }
 
 mod should {
+    use rstest_test::CountMessageOccurrence;
+
     use super::*;
 
     #[test]
@@ -58,9 +60,7 @@ mod should {
     fn rename() {
         let (output, _) = run_test("rename.rs");
 
-        TestResults::new()
-            .ok("test")
-            .assert(output);
+        TestResults::new().ok("test").assert(output);
     }
 
     mod accept_and_return {
@@ -198,6 +198,23 @@ mod should {
             .assert(output);
     }
 
+    #[rstest]
+    #[case("once.rs")]
+    #[case::no_return("once_no_return.rs")]
+    #[case::defined_type("once_defined_type.rs")]
+    fn accept_once_attribute_and_call_fixture_just_once(#[case] fname: &str) {
+        let project = prj(fname).with_nocapture();
+
+        let output = project.run_tests().unwrap();
+
+        // Just to see the errors if fixture doesn't compile
+        assert_in!(output.stderr.str(), "Exec fixture() just once");
+
+        let occurences = output.stderr.str().count("Exec fixture() just once");
+
+        assert_eq!(1, occurences);
+    }
+
     #[test]
     fn show_correct_errors() {
         let prj = prj("errors.rs");
@@ -239,9 +256,7 @@ mod should {
                   --> {}/src/lib.rs:16:29
                    |
                 16 | fn error_fixture_wrong_type(fixture: String) {{
-                   |                             ^^^^^^^
-                   |                             |
-        ",
+                   |                             ^^^^^^^",
                 name
             )
             .unindent()
@@ -276,5 +291,50 @@ mod should {
             )
             .unindent()
         );
+
+        assert_in!(
+            output.stderr.str(),
+            format!(
+                r#"
+                error: Cannot apply #[once] to async fixture.
+                  --> {}/src/lib.rs:38:3
+                   |
+                38 | #[once]
+                   |   ^^^^
+                "#,
+                name
+            )
+            .unindent()
+        );
+
+        assert_in!(
+            output.stderr.str(),
+            format!(
+                r#"
+                error: Cannot apply #[once] on generic fixture.
+                  --> {}/src/lib.rs:43:3
+                   |
+                43 | #[once]
+                   |   ^^^^
+                "#,
+                name
+            )
+            .unindent()
+        );
+
+        assert_in!(
+            output.stderr.str(),
+            format!(
+                r#"
+                error: Cannot apply #[once] on generic fixture.
+                  --> {}/src/lib.rs:49:3
+                   |
+                49 | #[once]
+                   |   ^^^^
+                "#,
+                name
+            )
+            .unindent()
+        );
     }
 }
