@@ -93,6 +93,15 @@ fn impl_input() {
         .assert(output);
 }
 
+#[test]
+fn use_mutable_fixture_in_parametric_argumnts() {
+    let (output, _) = run_test("use_mutable_fixture_in_parametric_argumnts.rs");
+
+    TestResults::new()
+        .ok("use_mutate_fixture::case_1::b_1")
+        .assert(output);
+}
+
 #[test]
 fn should_reject_no_item_function() {
     let (output, name) = run_test("reject_no_item_function.rs");
@@ -194,43 +203,25 @@ mod dump_input_values {
     fn should_not_compile_if_not_implement_debug(#[case] source: &str) {
         let (output, name) = run_test(source);
 
-        assert_in!(
+        assert_all_in!(
             output.stderr.str(),
-            format!(
-                "
-             --> {}/src/lib.rs:10:11
-              |
-           10 | fn single(fixture: S) {{}}
-              |           ^^^^^^^ `S` cannot be formatted using `{{:?}}`",
-                name
-            )
-            .unindent()
+            format!("--> {}/src/lib.rs:10:11", name),
+            "fn single(fixture: S) {}",
+            "^^^^^^^ `S` cannot be formatted using `{:?}`"
         );
 
         assert_in!(
             output.stderr.str(),
-            format!(
-                "
-              --> {}/src/lib.rs:15:10
-               |
-            15 | fn cases(s: S) {{}}
-               |          ^ `S` cannot be formatted using `{{:?}}`",
-                name
-            )
-            .unindent()
+            format!("--> {}/src/lib.rs:15:10", name),
+            "fn cases(s: S) {}",
+            "^ `S` cannot be formatted using `{:?}`"
         );
 
         assert_in!(
-            output.stderr.str().to_string(),
-            format!(
-                "
-              --> {}/src/lib.rs:20:11
-               |
-            20 | fn matrix(s: S) {{}}
-               |           ^ `S` cannot be formatted using `{{:?}}`",
-                name
-            )
-            .unindent()
+            output.stderr.str(),
+            format!("--> {}/src/lib.rs:20:11", name),
+            "fn matrix(s: S) {}",
+            "^ `S` cannot be formatted using `{:?}`"
         );
     }
 
@@ -883,6 +874,22 @@ fn rename() {
         .assert(output);
 }
 
+#[test]
+fn ignore_underscore_args() {
+    let (output, _) = run_test("ignore_args.rs");
+
+    TestResults::new()
+        .ok("test::case_1::_ignore3_1")
+        .ok("test::case_1::_ignore3_2")
+        .ok("test::case_1::_ignore3_3")
+        .ok("test::case_1::_ignore3_4")
+        .ok("test::case_2::_ignore3_1")
+        .ok("test::case_2::_ignore3_2")
+        .ok("test::case_2::_ignore3_3")
+        .ok("test::case_2::_ignore3_4")
+        .assert(output);
+}
+
 mod should_show_correct_errors {
     use std::process::Output;
 
@@ -967,9 +974,7 @@ mod should_show_correct_errors {
                   --> {}/src/lib.rs:16:29
                    |
                 16 | fn error_fixture_wrong_type(fixture: String, f: u32) {{}}
-                   |                             ^^^^^^^
-                   |                             |
-                ",
+                   |                             ^^^^^^^",
                 name
             )
             .unindent()
@@ -1274,18 +1279,10 @@ mod should_show_correct_errors {
     fn if_try_to_convert_literal_string_to_a_type_that_not_implement_from_str() {
         let (output, name) = execute();
 
+        assert_in!(output.stderr.str(), format!("--> {}/src/lib.rs:84:1", name));
         assert_in!(
             output.stderr.str(),
-            format!(
-                "
-                  --> {}/src/lib.rs:84:1
-                   |
-                83 | struct S;
-                   | --------- doesn't satisfy `S: FromStr`
-                ",
-                name
-            )
-            .unindent()
+            "| --------- doesn't satisfy `S: FromStr`"
         );
     }
 
